( cd usr/lib ; rm -rf libgpg-error.so.0 )
( cd usr/lib ; ln -sf libgpg-error.so.0.3.1 libgpg-error.so.0 )
( cd usr/lib ; rm -rf libgpg-error.so )
( cd usr/lib ; ln -sf libgpg-error.so.0.3.1 libgpg-error.so )
( cd usr/lib ; rm -rf libgpgme.so.11 )
( cd usr/lib ; ln -sf libgpgme.so.11.6.1 libgpgme.so.11 )
( cd usr/lib ; rm -rf libgpgme.so )
( cd usr/lib ; ln -sf libgpgme.so.11.6.1 libgpgme.so )
( cd usr/lib ; rm -rf libgpgme-pthread.so.11 )
( cd usr/lib ; ln -sf libgpgme-pthread.so.11.6.1 libgpgme-pthread.so.11 )
( cd usr/lib ; rm -rf libgpgme-pthread.so )
( cd usr/lib ; ln -sf libgpgme-pthread.so.11.6.1 libgpgme-pthread.so )
